@@ -29,18 +29,22 @@ for settings_key in dir(shrine_settings):
     if settings_key.startswith('__'):
         continue
     settings_value = getattr(shrine_settings, settings_key)
-    if settings_key == 'DATABASES':
+    if settings_key in ('DATABASES', 'TORNADO_CONFIG'):
         django_settings.DATABASES.update(settings_value)
 
     elif settings_key in ('INSTALLED_APPS',):
-        django_settings.INSTALLED_APPS = tuple(set(django_settings.INSTALLED_APPS + settings_value))
+        django_settings.INSTALLED_APPS = tuple(
+            set(django_settings.INSTALLED_APPS + settings_value))
 
     elif settings_key in ('TEMPLATE_PATH', 'STATIC_PATH',):
-        setattr(django_settings, settings_key, django_settings.PROJECT_PATH(settings_value))
+        setattr(django_settings, settings_key,
+                django_settings.PROJECT_PATH(settings_value))
 
     else:
         setattr(django_settings, settings_key, settings_value)
 
-LOCAL_FILE = lambda *path: join(abspath(dirname(shrine_settings.__file__)), *path)
+LOCAL_FILE = lambda *path: join(abspath(dirname(
+    shrine_settings.__file__)), *path)
+
 django_settings.LOCAL_FILE = LOCAL_FILE
 sys.path.append(LOCAL_FILE('..'))
